@@ -95,7 +95,7 @@ Debugger::Debugger(QTextEdit *tEdit,
     #else
         QString gdb = "gdb";
         QString objdump = "objdump";
-        exitMessage = "libc_start_main";
+        exitMessage = "libc_start";
     #endif
     cExitMessage = QRegExp("\\[Inferior .* exited");
 
@@ -132,7 +132,7 @@ Debugger::Debugger(QTextEdit *tEdit,
 
     checkGdbRunTimer = new QTimer;
     QObject::connect(checkGdbRunTimer, SIGNAL(timeout()), this, SLOT(checkGdbRun()), Qt::QueuedConnection);
-    checkGdbRunTimer->start(10000);
+    checkGdbRunTimer->start(20000);
 }
 
 void Debugger::emitStarted()
@@ -470,7 +470,7 @@ void Debugger::processAction(QString output, QString error)
         QSet<QString> general;
         QString ip;
         QSet<QString> segment;
-        segment << "cs" << "ds" << "ss" << "es" << "fs" << "gs";
+        segment << "cs" << "ds" << "ss" << "es" << "fs" << "gs" << "fs_base" << "gs_base";
         QSet<QString> flags;
         flags << "eflags" << "mxcsr";
         QSet<QString> fpu_info;
@@ -646,7 +646,7 @@ void Debugger::run()
         }
     #else
         doInput(QString("run < %1\n").arg(inputPath), none);
-        doInput(QString("p 0\n").arg(inputPath), none);
+        doInput(QString("p 0\n"), none);
     #endif
 }
 
