@@ -596,7 +596,7 @@ void MainWindow::changeCurrentSavedState(bool changed)
 void MainWindow::openFile()
 {
     QString fileName = QFileDialog::getOpenFileName(this, tr("Open file"), saveOpenDirectory,
-                                                    tr("Assembler source files (*.asm);;All files (*)"));
+                                                    tr("Assembler source files (*.asm *.S *.s);;All files (*)"));
     if (fileName.isEmpty()) {
         return;
     }
@@ -1558,7 +1558,7 @@ void MainWindow::findNext(const QString &pattern, Qt::CaseSensitivity cs, bool a
             connect(code, SIGNAL(cursorPositionChanged()), code, SLOT(highlightCurrentLine()));
             code->highlightCurrentLine();
             if (code->debugMode)
-                code->highlightDebugLine(code->currentDebugLine);
+                code->highlightDebugLine(code->currentDebugLine, false);
         }
     } else {
          //If true, find all
